@@ -653,9 +653,8 @@ void AppItem::showPreview()
         return;
 
     m_appPreviewTips = new PreviewContainer;
-
-    m_appPreviewTips->updateLayoutDirection(DockPosition);
     m_appPreviewTips->setWindowInfos(m_windowInfos, m_itemEntryInter->GetAllowedCloseWindows().value());
+    m_appPreviewTips->updateLayoutDirection(DockPosition);
 
     connect(m_appPreviewTips, &PreviewContainer::requestActivateWindow, this, &AppItem::requestActivateWindow, Qt::QueuedConnection);
     connect(m_appPreviewTips, &PreviewContainer::requestPreviewWindow, this, &AppItem::requestPreviewWindow, Qt::QueuedConnection);
@@ -668,9 +667,10 @@ void AppItem::showPreview()
     connect(m_appPreviewTips, &PreviewContainer::requestHidePopup, this, &AppItem::onResetPreview);
 
     // 预览标题显示方式的配置
-    DConfig config(QString("com.deepin.dde.dock.dconfig"), QString());
-    if (config.isValid() && config.keyList().contains("Dock_Show_Window_name"))
-        m_appPreviewTips->setTitleDisplayMode(config.value("Dock_Show_Window_name").toInt());
+    DConfig *config = DConfig::create("org.deepin.dde.dock", "org.deepin.dde.dock");
+    if (config->isValid() && config->keyList().contains("showWindowName"))
+        m_appPreviewTips->setTitleDisplayMode(config->value("showWindowName").toInt());
+    delete config;
 
     showPopupWindow(m_appPreviewTips, true);
 }
