@@ -25,51 +25,30 @@
 #include "constants.h"
 
 #include <QWidget>
-#include <QBoxLayout>
-#include <QLabel>
 
 #include <com_deepin_daemon_gesture.h>
 
 using namespace Dock;
-using Gesture = com::deepin::daemon::Gesture;
 
+class QBoxLayout;
+class QLabel;
 class TrayPluginItem;
 class PluginsItem;
-
-class MainPanelDelegate
-{
-public:
-    virtual bool appIsOnDock(const QString &appDesktop) = 0;
-};
-
-class DesktopWidget : public QWidget
-{
-    Q_OBJECT
-
-public:
-    explicit DesktopWidget(QWidget *parent) : QWidget(parent)
-    {
-    }
-};
-
 class DockItem;
 class PlaceholderItem;
 class AppDragWidget;
+class DesktopWidget;
 class MainPanelControl : public QWidget
 {
     Q_OBJECT
 public:
     explicit MainPanelControl(QWidget *parent = nullptr);
-    ~MainPanelControl() override;
 
     void setPositonValue(Position position);
     void setDisplayMode(DisplayMode dislayMode);
-    void getTrayVisableItemCount();
+    void resizeDockIcon();
     void updatePluginsLayout();
 
-    MainPanelDelegate *delegate() const;
-    void setDelegate(MainPanelDelegate *delegate);
-
 public slots:
     void insertItem(const int index, DockItem *item);
     void removeItem(DockItem *item);
@@ -79,17 +58,8 @@ signals:
     void itemMoved(DockItem *sourceItem, DockItem *targetItem);
     void itemAdded(const QString &appDesktop, int idx);
 
-protected:
-    void dragMoveEvent(QDragMoveEvent *e) override;
-    void dragEnterEvent(QDragEnterEvent *e) override;
-    void dragLeaveEvent(QDragLeaveEvent *e) override;
-    void dropEvent(QDropEvent *) override;
-    bool eventFilter(QObject *watched, QEvent *event) override;
-    void mousePressEvent(QMouseEvent *e) override;
-    void resizeEvent(QResizeEvent *event) override;
-
 private:
-    void initUi();
+    void initUI();
     void updateAppAreaSonWidgetSize();
     void updateMainPanelLayout();
     void updateDisplayMode();
@@ -104,15 +74,26 @@ private:
     void addPluginAreaItem(int index, QWidget *wdg);
     void removePluginAreaItem(QWidget *wdg);
 
+    // 拖拽相关
     void startDrag(DockItem *);
     DockItem *dropTargetItem(DockItem *sourceItem, QPoint point);
     void moveItem(DockItem *sourceItem, DockItem *targetItem);
     void handleDragMove(QDragMoveEvent *e, bool isFilter);
-    void paintEvent(QPaintEvent *event) override;
-    void resizeDockIcon();
-    void calcuDockIconSize(int w, int h, PluginsItem *trashPlugin, PluginsItem *shutdownPlugin, PluginsItem *keyboardPlugin, PluginsItem *notificationPlugin);
+    void calcuDockIconSize(int w, int h, int traySize);
     void resizeDesktopWidget();
     bool checkNeedShowDesktop();
+    bool appIsOnDock(const QString &appDesktop);
+    
+protected:
+    void dragMoveEvent(QDragMoveEvent *e) override;
+    void dragEnterEvent(QDragEnterEvent *e) override;
+    void dragLeaveEvent(QDragLeaveEvent *e) override;
+    void dropEvent(QDropEvent *) override;
+    bool eventFilter(QObject *watched, QEvent *event) override;
+    void enterEvent(QEvent *event) override;
+    void mousePressEvent(QMouseEvent *e) override;
+    void resizeEvent(QResizeEvent *event) override;
+    void paintEvent(QPaintEvent *event) override;
 
 private:
     QBoxLayout *m_mainPanelLayout;
@@ -121,7 +102,7 @@ private:
     QBoxLayout *m_fixedAreaLayout;  //
     QLabel *m_fixedSpliter;         // 固定区域与应用区域间的分割线
     QWidget *m_appAreaWidget;       // 应用区域
-    QWidget *m_appAreaSonWidget;    // 子应用区域
+    QWidget *m_appAreaSonWidget;    // 子应用区域，所在位置根据显示模式手动指定
     QBoxLayout *m_appAreaSonLayout; //
     QLabel *m_appSpliter;           // 应用区域与托盘区域间的分割线
     QWidget *m_trayAreaWidget;      // 托盘区域
@@ -133,16 +114,14 @@ private:
 
     Position m_position;
     QPointer<PlaceholderItem> m_placeholderItem;
-    MainPanelDelegate *m_delegate;
     QString m_draggingMimeKey;
     AppDragWidget *m_appDragWidget;
     DisplayMode m_dislayMode;
     QPoint m_mousePressPos;
-    int m_trayIconCount;
-    TrayPluginItem *m_tray = nullptr;
-    bool m_isHover;         // 判断鼠标是否移到desktop区域
-    bool m_needRecoveryWin; // 判断鼠标移出desktop区域是否恢复之前窗口
+    TrayPluginItem *m_tray;
     int m_dragIndex = -1;   // 记录应用区域被拖拽图标的位置
+
+    PluginsItem *m_trashItem;       // 垃圾箱插件（需要特殊处理一下）
 };
 
 #endif // MAINPANELCONTROL_H
