@@ -29,6 +29,9 @@
 
 #include <QPainter>
 #include <QApplication>
+#include <QDBusPendingCall>
+#include <QtConcurrent>
+#include <QFuture>
 
 #include <xcb/xproto.h>
 
@@ -38,7 +41,6 @@ DGUI_USE_NAMESPACE
 
 const QStringList ItemCategoryList {"ApplicationStatus", "Communications", "SystemServices", "Hardware"};
 const QStringList ItemStatusList {"Passive", "Active", "NeedsAttention"};
-const QStringList LeftClickInvalidIdList {"sogou-qimpanel",};
 QPointer<DockPopupWindow> SNITrayWidget::PopupWindow = nullptr;
 Dock::Position SNITrayWidget::DockPosition = Dock::Position::Top;
 using namespace Dock;
@@ -88,7 +90,7 @@ SNITrayWidget::SNITrayWidget(const QString &sniServicePath, QWidget *parent)
     setOwnerPID(conn.interface()->servicePid(m_dbusService));
 
     m_sniInter = new StatusNotifierItem(m_dbusService, m_dbusPath, QDBusConnection::sessionBus(), this);
-
+    m_sniInter->setSync(false);
     if (!m_sniInter->isValid()) {
         qDebug() << "SNI dbus interface is invalid!" << m_dbusService << m_dbusPath << m_sniInter->lastError();
         return;
@@ -155,24 +157,7 @@ SNITrayWidget::SNITrayWidget(const QString &sniServicePath, QWidget *parent)
 
 QString SNITrayWidget::itemKeyForConfig()
 {
-    QString key;
-
-    do {
-        key = m_sniId;
-        if (!key.isEmpty()) {
-            break;
-        }
-
-        key = QDBusInterface(m_dbusService, m_dbusPath, StatusNotifierItem::staticInterfaceName())
-              .property("Id").toString();
-        if (!key.isEmpty()) {
-            break;
-        }
-
-        key = m_sniServicePath;
-    } while (false);
-
-    return QString("sni:%1").arg(key);
+    return QString("sni:%1").arg(m_sniId.isEmpty() ? m_sniServicePath : m_sniId);
 }
 
 void SNITrayWidget::updateIcon()
@@ -184,12 +169,18 @@ void SNITrayWidget::sendClick(uint8_t mouseButton, int x, int y)
 {
     switch (mouseButton) {
     case XCB_BUTTON_INDEX_1:
-        // left button click invalid
-        if (LeftClickInvalidIdList.contains(m_sniId)) {
-            showContextMenu(x, y);
-        } else {
-            m_sniInter->Activate(x, y);
-        }
+    {
+        QFuture<void> future = QtConcurrent::run([ = ] {
+            StatusNotifierItem inter(m_dbusService, m_dbusPath, QDBusConnection::sessionBus());
+            QDBusPendingReply<> reply = inter.Activate(x, y);
+            // try to invoke context menu while calling activate get a error.
+            // primarily work for apps using libappindicator.
+            reply.waitForFinished();
+            if (reply.isError()) {
+                showContextMenu(x,y);
+            }
+        });
+    }
         break;
     case XCB_BUTTON_INDEX_2:
         m_sniInter->SecondaryActivate(x, y);
@@ -293,6 +284,8 @@ void SNITrayWidget::initMenu()
     qDebug() << "generate the sni menu object";
 
     m_menu = m_dbusMenuImporter->menu();
+    if (m_menu && !m_menu->parentWidget())
+        m_menu->setParent(topLevelWidget(), Qt::Popup);
 
     qDebug() << "the sni menu obect is:" << m_menu;
 }
