@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
 <context>
     <name>AbstractPluginsController</name>
     <message>
@@ -6,6 +6,43 @@
         <translation>འཇུག་ཆས་%1དང་རྒྱུད་ཁོངས་ཀྱི་པར་གཞི་ཕན་ཚུན་མི་མཐུན་པ།</translation>
     </message>
 </context>
+<context>
+    <name>AirplaneModeApplet</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>འཕུར་སྐྱོད་དཔེ་རྣམ།</translation>
+    </message>
+</context>
+<context>
+    <name>AirplaneModeItem</name>
+    <message>
+        <source>Airplane mode enabled</source>
+        <translation>འཕུར་བའི་རྣམ་པ་ཕྱེ་བ།</translation>
+    </message>
+    <message>
+        <source>Turn off</source>
+        <translation>སོ་སྔོན་ཁ་རྒྱོབ།</translation>
+    </message>
+    <message>
+        <source>Turn on</source>
+        <translation>སོ་སྔོན་ཁ་ཕྱེ།</translation>
+    </message>
+    <message>
+        <source>Airplane Mode settings</source>
+        <translation>འཕུར་སྐྱོད་དཔེ་རྣམ་སྒྲིག་འགོད།</translation>
+    </message>
+    <message>
+        <source>Airplane mode disabled</source>
+        <translation>འཕུར་བའི་རྣམ་པ་ཁ་རྒྱག་པ།</translation>
+    </message>
+</context>
+<context>
+    <name>AirplaneModePlugin</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>འཕུར་སྐྱོད་དཔེ་རྣམ།</translation>
+    </message>
+</context>
 <context>
     <name>AppDragWidget</name>
     <message>
@@ -84,21 +121,6 @@
         <translation>དུས་ཚོད་སྒྲིག་འགོད།</translation>
     </message>
 </context>
-<context>
-    <name>DeviceItem</name>
-    <message>
-        <source>Enable network</source>
-        <translation>དྲ་རྒྱ་སྤྱོད་པ།</translation>
-    </message>
-    <message>
-        <source>Disable network</source>
-        <translation>དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
-    </message>
-    <message>
-        <source>Network settings</source>
-        <translation>དྲ་རྒྱ་སྒྲིག་འགོད།</translation>
-    </message>
-</context>
 <context>
     <name>DialogManager</name>
     <message>
@@ -217,8 +239,95 @@
         <translation>རྣམ་པ།</translation>
     </message>
     <message>
-        <source>Plugins</source>
-        <translation>འཇུག་ཆས།</translation>
+        <source>Dock settings</source>
+        <translation>ལས་འགན་ཚན་བྱང་སྒྲིག་འགོད།</translation>
+    </message>
+</context>
+<context>
+    <name>ModuleWidget</name>
+    <message>
+        <source>Size</source>
+        <translation>ཆེ་ཆུང་།</translation>
+    </message>
+    <message>
+        <source>Multiple Displays</source>
+        <translation>བརྙན་མང་མངོན་སྟོན་སྒྲིག་འགོད།</translation>
+    </message>
+    <message>
+        <source>Plugin Area</source>
+        <translation>ལྷུ་ལག་ཁུལ་ཁོངས།</translation>
+    </message>
+    <message>
+        <source>Select which icons appear in the Dock</source>
+        <translation>ལས་འགན་ཚན་བྱང་གི་ལྷུ་ལག་ཁུལ་དུ་མངོན་པའི་པར་རིས་འདེམས་པ།</translation>
+    </message>
+    <message>
+        <source>Fashion mode</source>
+        <translation>དར་སྲོལ་དཔེ་རྣམ།</translation>
+    </message>
+    <message>
+        <source>Efficient mode</source>
+        <translation>ལས་ཆོད་ཆེ་བའི་དཔེ་རྣམ།</translation>
+    </message>
+    <message>
+        <source>Mode</source>
+        <translation>དཔེ་རྣམ།</translation>
+    </message>
+    <message>
+        <source>Top</source>
+        <translation>གོང་།</translation>
+    </message>
+    <message>
+        <source>Bottom</source>
+        <translation>འོག</translation>
+    </message>
+    <message>
+        <source>Left</source>
+        <translation>གཡོན།</translation>
+    </message>
+    <message>
+        <source>Right</source>
+        <translation>གཡས།</translation>
+    </message>
+    <message>
+        <source>Location</source>
+        <translation>གནས་ས།</translation>
+    </message>
+    <message>
+        <source>Keep shown</source>
+        <translation>རྟག་ཏུ་མངོན་པ།</translation>
+    </message>
+    <message>
+        <source>Keep hidden</source>
+        <translation>རྟག་ཏུ་ཡིབ་པ།</translation>
+    </message>
+    <message>
+        <source>Smart hide</source>
+        <translation>རིག་ནུས་གབ་ཡིབ།</translation>
+    </message>
+    <message>
+        <source>Status</source>
+        <translation>རྣམ་པ།</translation>
+    </message>
+    <message>
+        <source>Small</source>
+        <translation>ཆུང་ངུ།</translation>
+    </message>
+    <message>
+        <source>Large</source>
+        <translation>ཆེ་བ།</translation>
+    </message>
+    <message>
+        <source>Show Dock</source>
+        <translation>ལས་འགན་ཚན་བྱང་གི་གནས་ས།</translation>
+    </message>
+    <message>
+        <source>On screen where the cursor is</source>
+        <translation>ཙི་གུའི་གནས་ཡུལ་ལྟར་མངོན་པ།</translation>
+    </message>
+    <message>
+        <source>Only on main screen</source>
+        <translation>བརྙན་ཡོལ་ཨ་མ་ཁོ་ན་མངོན་པ།</translation>
     </message>
 </context>
 <context>
@@ -232,92 +341,6 @@
         <translation>བསྡད་པ་གཙང་སེལ།</translation>
     </message>
 </context>
-<context>
-    <name>NetworkItem</name>
-    <message>
-        <source>Disable wired connection</source>
-        <translation>སྐུད་ཡོད་དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
-    </message>
-    <message>
-        <source>Enable wired connection</source>
-        <translation>སྐུད་ཡོད་དྲ་རྒྱ་སྤྱོད་པ།</translation>
-    </message>
-    <message>
-        <source>Disable wireless connection</source>
-        <translation>སྐུད་མེད་དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
-    </message>
-    <message>
-        <source>Enable wireless connection</source>
-        <translation>སྐུད་མེད་དྲ་རྒྱ་སྤྱོད་པ།</translation>
-    </message>
-    <message>
-        <source>Disable network</source>
-        <translation>དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
-    </message>
-    <message>
-        <source>Enable network</source>
-        <translation>དྲ་རྒྱ་སྤྱོད་པ།</translation>
-    </message>
-    <message>
-        <source>Network settings</source>
-        <translation>དྲ་རྒྱ་སྒྲིག་འགོད།</translation>
-    </message>
-    <message>
-        <source>Device disabled</source>
-        <translation>སྒྲིག་ཆས་སྤྱོད་མི་ཆོག</translation>
-    </message>
-    <message>
-        <source>Wireless connection: %1</source>
-        <translation>སྐུད་མེད་དྲ་རྒྱ། %1</translation>
-    </message>
-    <message>
-        <source>Wired connection: %1</source>
-        <translation>སྐུད་ཡོད་དྲ་རྒྱ། %1</translation>
-    </message>
-    <message>
-        <source>Not connected</source>
-        <translation>སྦྲེལ་མེད་པ། </translation>
-    </message>
-    <message>
-        <source>Connecting</source>
-        <translation>སྦྲེལ་བཞིན་པ། </translation>
-    </message>
-    <message>
-        <source>Connected but no Internet access</source>
-        <translation>དྲ་རྒྱ་དང་འབྲེལ་ཟིན་ཡང་མཉམ་སྦྲེལ་དྲ་རྒྱར་འཛུལ་མི་ཐུབ།</translation>
-    </message>
-    <message>
-        <source>Network cable unplugged</source>
-        <translation>དྲ་སྐུད་མཐུད་མི་འདུག</translation>
-    </message>
-    <message>
-        <source>Wireless Network</source>
-        <translation>སྐུད་མེད་དྲ་རྒྱ།</translation>
-    </message>
-    <message>
-        <source>Wired Network</source>
-        <translation>སྐུད་ཡོད་དྲ་རྒྱ།</translation>
-    </message>
-    <message>
-        <source>Connection failed</source>
-        <translation>འབྲེལ་མཐུད་བྱེད་མ་ཐུབ།</translation>
-    </message>
-</context>
-<context>
-    <name>NetworkPlugin</name>
-    <message>
-        <source>Network</source>
-        <translation>དྲ་རྒྱ། </translation>
-    </message>
-    <message>
-        <source>Wired Network</source>
-        <translation>སྐུད་ཡོད་དྲ་རྒྱ།</translation>
-    </message>
-    <message>
-        <source>Wired Network %1</source>
-        <translation>སྐུད་ཡོད་དྲ་རྒྱ་%1</translation>
-    </message>
-</context>
 <context>
     <name>OnboardPlugin</name>
     <message>
@@ -355,10 +378,6 @@
         <source>Charging %1, %2 hr %3 min until full</source>
         <translation>གློག་གསོག་བཞིན་ཡོད་%1 ད་དུང་ཆུ་ཚོད་%2དང་སྐར་མ་%3དགོས།</translation>
     </message>
-    <message>
-        <source>Charged</source>
-        <translation>ཁེངས་ཟིན།</translation>
-    </message>
     <message>
         <source>Capacity %1</source>
         <translation>གློག་ཚད་%1</translation>
@@ -376,6 +395,14 @@
         <translation>གློག་ཚད་%1 ཁེངས་ཟིན།</translation>
     </message>
 </context>
+<context>
+    <name>SettingsModule</name>
+    <message>
+        <source>Dock</source>
+        <translation>ལས་འགན་ཚན་བྱང་།</translation>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
+    </message>
+</context>
 <context>
     <name>ShowDesktopPlugin</name>
     <message>
@@ -473,6 +500,10 @@
         <source>Trash - %1 files</source>
         <translation>སྙིགས་སྣོད་ཀྱི་ཡིག་ཆ་%1</translation>
     </message>
+    <message>
+        <source>Move to Trash</source>
+        <translation>སྙིགས་སྣོད་ནང་བླུགས་པ།</translation>
+    </message>
 </context>
 <context>
     <name>TrashWidget</name>
@@ -485,22 +516,4 @@
         <translation>གསལ་ཐོ་གཙང་སེལ།</translation>
     </message>
 </context>
-<context>
-    <name>TrayPlugin</name>
-    <message>
-        <source>System Tray</source>
-        <translation>རྒྱུད་ཁོངས་སྡེར་མ།</translation>
-    </message>
-</context>
-<context>
-    <name>WirelessList</name>
-    <message>
-        <source>Wireless Network</source>
-        <translation>སྐུད་མེད་དྲ་རྒྱ།</translation>
-    </message>
-    <message>
-        <source>Wireless Network %1</source>
-        <translation>སྐུད་མེད་དྲ་རྒྱ་%1</translation>
-    </message>
-</context>
 </TS>
\ No newline at end of file
